#
# spec file for package python-azure-graphrbac
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-azure-graphrbac
Version:        0.61.2
Release:        1.3
Summary:        Microsoft Azure Graph RBAC Client Library
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/Azure/azure-sdk-for-python
Source:         https://files.pythonhosted.org/packages/source/a/azure_graphrbac/azure_graphrbac-%{version}.tar.gz
BuildRequires:  %{python_module azure-nspkg >= 3.0.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-azure-nspkg >= 3.0.0
Requires:       python-msrest >= 0.6.21
Requires:       (python-azure-common >= 1.1 with python-azure-common < 2.0.0)
Requires:       (python-msrestazure >= 0.4.32 with python-msrestazure < 2.0.0)
Conflicts:      python-azure-sdk <= 2.0.0
%if 0%{?sle_version} >= 150400
Obsoletes:      python3-azure-graphrbac <= 0.61.1
%endif
BuildArch:      noarch

%python_subpackages

%description
This is the Microsoft Azure Graph RBAC Client Library.

This package has been tested with Python 2.7, 3.4, 3.5, 3.6 and 3.7.

%prep
%setup -q -n azure_graphrbac-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%{python_expand # delete common files
rm -rf %{buildroot}%{$python_sitelib}/azure/__init__.*
rm -rf %{buildroot}%{$python_sitelib}/azure/__pycache__
}

%files %{python_files}
%doc CHANGELOG.md README.md
%license LICENSE
%{python_sitelib}/azure/graphrbac
%{python_sitelib}/azure_graphrbac-*.dist-info

%changelog
* Fri Nov  1 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.61.2
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Adjust upstream source name in spec file
- Drop extra LICENSE.txt as upstream now ships its own
- Remove unzip package from BuildRequires
- Rename HISTORY.rst to CHANGELOG.md in %%files section
- Rename LICENSE.txt to LICENSE in %%files section
- Rename README.rst to README.md in %%files section
- Switch source archive format to TAR.GZ
- Update Requires from setup.py
* Fri May  3 2024 Robert Schweikert <rjschwei@suse.com>
- Change version setting of Obsoletes to <= to trigger python3
  binary removal since there was no source version bump
* Thu Apr  4 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Switch package to modern Python Stack on SLE-15
  + Use Python 3.11 on SLE-15 by default
  + Add Obsoletes for old python3 package on SLE-15
  + Drop support for older Python versions
- Switch build system from setuptools to pyproject.toml
  + Add python-pip and python-wheel to BuildRequires
  + Replace %%python_build with %%pyproject_wheel
  + Replace %%python_install with %%pyproject_install
  + Update name for dist directory in %%files section
- Drop setting default file attributes in %%files section
- Use modern RPM macros to express version dependencies
* Thu Nov 26 2020 Robert Schweikert <rjschwei@suse.com>
- Only build Python3 flavors for distributions 15 and greater
* Fri Oct  4 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.61.1
  + For detailed information about changes see the
    HISTORY.txt file provided with this package
- Drop patches to support older versions of setuptools as
  SLE-12 is now shipping with a recent enough version
  + ag_drop-compatible-releases-operator.patch
  + ag_drop-extras-require.patch
* Thu Apr 11 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.53.0
  + For detailed information about changes see the
    HISTORY.txt file provided with this package
- Add patch to drop extras_require field from setup.py,
  required for SLES12 as the setuptools version is too old
  + ag_drop-extras-require.patch
- Bump minimum version for namespace packages
  to 3.0.0 in BuildRequires and Requires
- Remove python-devel package from BuildRequires
- Refresh patches for new version
  + ag_drop-compatible-releases-operator.patch
- Run fdupes to hardlink duplicate files
  + Add fdupes to BuildRequires
  + Add %%fdupes invocation to %%install
- Update %%description from setup.py
- Update BuildRequires and Requires from setup.py
* Tue Mar  6 2018 adrian.glaubitz@suse.com
- New upstream release
  + Version 0.40.0
- Move LICENSE.txt from %%doc to %%license section
- Refresh patches for new version
- Update Requires from setup.py
- Update %%description from setup.py
- Add patch ag_drop-compatible-releases-operator.patch
- Drop patch ag_drop-compatible-releases-operaror.patch
* Wed Jan 17 2018 adrian.glaubitz@suse.com
- New upstream release
  + Version 0.33.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Install HISTORY.rst into doc directory
* Wed Oct  4 2017 adrian.glaubitz@suse.com
- New upstream release
  + Version 0.32.0
- Remove versioning for namespace packages in Requires
- Update Requires from setup.py
- Add namespace packages to BuildRequires
- Remove namespace files in %%install target
- Explicitly specify Python files of the package in %%files
* Tue Sep 12 2017 adrian.glaubitz@suse.com
- New upstream release
  + Version 0.31.0
- Update Requires from upstream setup.py
  + Bump python-msrestazure Requires to 0.4.11
- Update Summary and Description from upstream
- Update patch to drop compatible releases operator from setup.py
  + ag_drop-compatible-releases-operator.patch
* Thu Jul 13 2017 adrian.glaubitz@suse.com
- Add python-azure-nspkg to Requires
* Tue Jun 27 2017 adrian.glaubitz@suse.com
- Initial build
  + Version 0.30.0
- Add patch to drop compatible releases operator from setup.py,
  required for SLES12 as the setuptools version is too old
  + ag_drop-compatible-releases-operaror.patch
